@@ -9,7 +9,8 @@
 spark_config_value <- function(config, name, default = NULL) {
   if (getOption("sparklyr.test.enforce.config", FALSE) && any(grepl("^sparklyr.", name))) {
     settings <- get("spark_config_settings")()
-    if (!any(name %in% settings$name)) {
+    if (!any(name %in% settings$name) &&
+        !grepl("^sparklyr\\.shell\\.", name)) {
       stop("Config value '", name[[1]], "' not described in spark_config_settings()")
     }
   }
@@ -28,6 +29,7 @@ spark_config_value <- function(config, name, default = NULL) {
     value <- config[[name_primary]]
   }
 
+  if (is.language(value)) value <- rlang::as_closure(value)
   if (is.function(value)) value <- value()
   value
 }
