@@ -41,9 +41,12 @@
 ft_feature_hasher <- function(x, input_cols = NULL, output_col = NULL,
                               num_features = 2^18, categorical_cols = NULL,
                               uid = random_string("feature_hasher_"), ...) {
+  check_dots_used()
   UseMethod("ft_feature_hasher")
 }
 
+ml_feature_hasher <- ft_feature_hasher
+
 #' @export
 ft_feature_hasher.spark_connection <- function(x, input_cols = NULL, output_col = NULL,
                                                num_features = 2^18, categorical_cols = NULL,
@@ -56,13 +59,13 @@ ft_feature_hasher.spark_connection <- function(x, input_cols = NULL, output_col
     uid = uid
   ) %>%
     c(rlang::dots_list(...)) %>%
-    ml_validator_feature_hasher()
+    validator_ml_feature_hasher()
 
-  jobj <- ml_new_transformer(
+  jobj <- spark_pipeline_stage(
     x, "org.apache.spark.ml.feature.FeatureHasher",
     input_cols = .args[["input_cols"]], output_col =.args[["output_col"]], uid = .args[["uid"]]) %>%
     invoke("setNumFeatures", .args[["num_features"]]) %>%
-    maybe_set_param("setCategoricalCols", .args[["categorical_cols"]])
+    jobj_set_param("setCategoricalCols", .args[["categorical_cols"]])
 
   new_ml_feature_hasher(jobj)
 }
@@ -100,10 +103,10 @@ ft_feature_hasher.tbl_spark <- function(x, input_cols = NULL, output_col = NULL,
 }
 
 new_ml_feature_hasher <- function(jobj) {
-  new_ml_transformer(jobj, subclass = "ml_feature_hasher")
+  new_ml_transformer(jobj, class = "ml_feature_hasher")
 }
 
-ml_validator_feature_hasher <- function(.args) {
+validator_ml_feature_hasher <- function(.args) {
   .args[["input_cols"]] <- cast_nullable_string_list(.args[["input_cols"]])
   .args[["output_col"]] <- cast_nullable_string(.args[["output_col"]])
   .args[["categorical_cols"]] <- cast_nullable_string_list(.args[["categorical_cols"]])
